.. _api-config:

======
Config
======

.. _api-config-class:

.. autoclass:: protean.domain.config.Config

.. _api-config-from_envvar:

.. automethod:: protean.domain.config.Config.from_envvar

.. _api-config-from_pyfile:

.. automethod:: protean.domain.config.Config.from_pyfile

.. _api-config-from_object:

.. automethod:: protean.domain.config.Config.from_object

.. _api-config-from_json:

.. automethod:: protean.domain.config.Config.from_json

.. _api-config-from_mapping:

.. automethod:: protean.domain.config.Config.from_mapping
